@@ -1,5 +1,11 @@
 /* This is a generated file, edit the .stub.php file instead.
- * Stub hash: 12899073f3791c5da31aa555c0e612ee1faadf55 */
+ * Stub hash: 3dbc84896823c9aaa9ac8aeef8841266920c3e50 */
+
+ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_exit, 0, 0, IS_NEVER, 0)
+	ZEND_ARG_TYPE_MASK(0, status, MAY_BE_STRING|MAY_BE_LONG, "0")
+ZEND_END_ARG_INFO()
+
+#define arginfo_die arginfo_exit
 
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_zend_version, 0, 0, IS_STRING, 0)
 ZEND_END_ARG_INFO()
@@ -127,7 +133,7 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_get_required_files arginfo_func_get_args
 
-ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_trigger_error, 0, 1, _IS_BOOL, 0)
+ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_trigger_error, 0, 1, IS_TRUE, 0)
 	ZEND_ARG_TYPE_INFO(0, message, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, error_level, IS_LONG, 0, "E_USER_NOTICE")
 ZEND_END_ARG_INFO()
@@ -218,6 +224,21 @@ ZEND_END_ARG_INFO()
 #define arginfo_gc_status arginfo_func_get_args
 
 
+ZEND_FRAMELESS_FUNCTION(property_exists, 2);
+static const zend_frameless_function_info frameless_function_infos_property_exists[] = {
+	{ ZEND_FRAMELESS_FUNCTION_NAME(property_exists, 2), 2 },
+	{ 0 },
+};
+
+ZEND_FRAMELESS_FUNCTION(class_exists, 1);
+ZEND_FRAMELESS_FUNCTION(class_exists, 2);
+static const zend_frameless_function_info frameless_function_infos_class_exists[] = {
+	{ ZEND_FRAMELESS_FUNCTION_NAME(class_exists, 1), 1 },
+	{ ZEND_FRAMELESS_FUNCTION_NAME(class_exists, 2), 2 },
+	{ 0 },
+};
+
+ZEND_FUNCTION(exit);
 ZEND_FUNCTION(zend_version);
 ZEND_FUNCTION(func_num_args);
 ZEND_FUNCTION(func_get_arg);
@@ -277,17 +298,18 @@ ZEND_FUNCTION(gc_enable);
 ZEND_FUNCTION(gc_disable);
 ZEND_FUNCTION(gc_status);
 
-
 static const zend_function_entry ext_functions[] = {
+	ZEND_FE(exit, arginfo_exit)
+	ZEND_RAW_FENTRY("die", zif_exit, arginfo_die, 0, NULL, NULL)
 	ZEND_FE(zend_version, arginfo_zend_version)
 	ZEND_FE(func_num_args, arginfo_func_num_args)
 	ZEND_FE(func_get_arg, arginfo_func_get_arg)
 	ZEND_FE(func_get_args, arginfo_func_get_args)
 	ZEND_FE(strlen, arginfo_strlen)
-	ZEND_SUPPORTS_COMPILE_TIME_EVAL_FE(strcmp, arginfo_strcmp)
-	ZEND_SUPPORTS_COMPILE_TIME_EVAL_FE(strncmp, arginfo_strncmp)
-	ZEND_SUPPORTS_COMPILE_TIME_EVAL_FE(strcasecmp, arginfo_strcasecmp)
-	ZEND_SUPPORTS_COMPILE_TIME_EVAL_FE(strncasecmp, arginfo_strncasecmp)
+	ZEND_RAW_FENTRY("strcmp", zif_strcmp, arginfo_strcmp, ZEND_ACC_COMPILE_TIME_EVAL, NULL, NULL)
+	ZEND_RAW_FENTRY("strncmp", zif_strncmp, arginfo_strncmp, ZEND_ACC_COMPILE_TIME_EVAL, NULL, NULL)
+	ZEND_RAW_FENTRY("strcasecmp", zif_strcasecmp, arginfo_strcasecmp, ZEND_ACC_COMPILE_TIME_EVAL, NULL, NULL)
+	ZEND_RAW_FENTRY("strncasecmp", zif_strncasecmp, arginfo_strncasecmp, ZEND_ACC_COMPILE_TIME_EVAL, NULL, NULL)
 	ZEND_FE(error_reporting, arginfo_error_reporting)
 	ZEND_FE(define, arginfo_define)
 	ZEND_FE(defined, arginfo_defined)
@@ -301,17 +323,17 @@ static const zend_function_entry ext_functions[] = {
 	ZEND_FE(get_mangled_object_vars, arginfo_get_mangled_object_vars)
 	ZEND_FE(get_class_methods, arginfo_get_class_methods)
 	ZEND_FE(method_exists, arginfo_method_exists)
-	ZEND_FE(property_exists, arginfo_property_exists)
-	ZEND_FE(class_exists, arginfo_class_exists)
+	ZEND_RAW_FENTRY("property_exists", zif_property_exists, arginfo_property_exists, 0, frameless_function_infos_property_exists, NULL)
+	ZEND_RAW_FENTRY("class_exists", zif_class_exists, arginfo_class_exists, 0, frameless_function_infos_class_exists, NULL)
 	ZEND_FE(interface_exists, arginfo_interface_exists)
 	ZEND_FE(trait_exists, arginfo_trait_exists)
 	ZEND_FE(enum_exists, arginfo_enum_exists)
 	ZEND_FE(function_exists, arginfo_function_exists)
 	ZEND_FE(class_alias, arginfo_class_alias)
 	ZEND_FE(get_included_files, arginfo_get_included_files)
-	ZEND_FALIAS(get_required_files, get_included_files, arginfo_get_required_files)
+	ZEND_RAW_FENTRY("get_required_files", zif_get_included_files, arginfo_get_required_files, 0, NULL, NULL)
 	ZEND_FE(trigger_error, arginfo_trigger_error)
-	ZEND_FALIAS(user_error, trigger_error, arginfo_user_error)
+	ZEND_RAW_FENTRY("user_error", zif_trigger_error, arginfo_user_error, 0, NULL, NULL)
 	ZEND_FE(set_error_handler, arginfo_set_error_handler)
 	ZEND_FE(restore_error_handler, arginfo_restore_error_handler)
 	ZEND_FE(set_exception_handler, arginfo_set_exception_handler)
@@ -342,18 +364,12 @@ static const zend_function_entry ext_functions[] = {
 	ZEND_FE_END
 };
 
-
-static const zend_function_entry class_stdClass_methods[] = {
-	ZEND_FE_END
-};
-
 static zend_class_entry *register_class_stdClass(void)
 {
 	zend_class_entry ce, *class_entry;
 
-	INIT_CLASS_ENTRY(ce, "stdClass", class_stdClass_methods);
-	class_entry = zend_register_internal_class_ex(&ce, NULL);
-	class_entry->ce_flags |= ZEND_ACC_ALLOW_DYNAMIC_PROPERTIES;
+	INIT_CLASS_ENTRY(ce, "stdClass", NULL);
+	class_entry = zend_register_internal_class_with_flags(&ce, NULL, ZEND_ACC_ALLOW_DYNAMIC_PROPERTIES);
 
 	zend_string *attribute_name_AllowDynamicProperties_class_stdClass_0 = zend_string_init_interned("AllowDynamicProperties", sizeof("AllowDynamicProperties") - 1, 1);
 	zend_add_class_attribute(class_entry, attribute_name_AllowDynamicProperties_class_stdClass_0, 0);
